@@ -20,7 +20,6 @@
 from __future__ import absolute_import
 
 import ctypes
-from ctypes.util import find_library
 import os
 
 from vdsm.gluster import exception as ge
@@ -167,8 +166,7 @@ def checkVolumeEmpty(volumeId, host=GLUSTER_VOL_HOST,
 
 # C function prototypes for using the library gfapi
 
-_lib = ctypes.CDLL(find_library("gfapi"),
-                   use_errno=True)
+_lib = ctypes.CDLL("libgfapi.so.0", use_errno=True)
 
 _glfs_new = ctypes.CFUNCTYPE(
     ctypes.c_void_p, ctypes.c_char_p)(('glfs_new', _lib))
@@ -219,7 +217,7 @@ def volumeStatvfs(volumeName, host=GLUSTER_VOL_HOST,
                   port=GLUSTER_VOL_PORT,
                   protocol=GLUSTER_VOL_PROTOCOL):
     module = "vdsm.gluster.gfapi"
-    command = [constants.EXT_PYTHON, '-m', module, '-v', volumeName,
+    command = [sys.executable, '-m', module, '-v', volumeName,
                '-p', str(port), '-H', host, '-t', protocol, '-c', 'statvfs']
 
     # to include /usr/share/vdsm in python path
@@ -250,7 +248,7 @@ def volumeEmptyCheck(volumeName, host=GLUSTER_VOL_HOST,
                      port=GLUSTER_VOL_PORT,
                      protocol=GLUSTER_VOL_PROTOCOL):
     module = "gluster.gfapi"
-    command = [constants.EXT_PYTHON, '-m', module, '-v', volumeName,
+    command = [sys.executable, '-m', module, '-v', volumeName,
                '-p', str(port), '-H', host, '-t', protocol, '-c', 'readdir']
 
     # to include /usr/share/vdsm in python path
