@@ -29,7 +29,8 @@ shared utilities and common code for the virt package
 import os.path
 import threading
 
-from vdsm.utils import monotonic_time, rmFile
+from vdsm.common.fileutils import rm_file
+from vdsm.common.time import monotonic_time
 
 log = logging.getLogger('virt.utils')
 
@@ -124,8 +125,8 @@ class ExpiringCache(object):
 
 def cleanup_guest_socket(sock):
     if os.path.islink(sock):
-        rmFile(os.path.realpath(sock))
-    rmFile(sock)
+        rm_file(os.path.realpath(sock))
+    rm_file(sock)
 
 
 class DynamicBoundedSemaphore(object):
@@ -210,8 +211,8 @@ class DynamicBoundedSemaphore(object):
                 self.release()
 
 
-def is_kvm(vm_conf):
-    return 'containerType' not in vm_conf.get('custom', {})
+def is_kvm(vm_custom):
+    return 'containerType' not in vm_custom
 
 
 class TeardownError(Exception):
