@@ -18,7 +18,6 @@
 # Refer to the README and COPYING files for full details of the license
 #
 import logging
-import os.path
 import threading
 from collections import defaultdict
 
@@ -36,12 +35,11 @@ from vdsm.protocoldetector import MultiProtocolAcceptor
 from vdsm import API
 from vdsm import schedule
 from vdsm import utils
-from vdsm.network import connectivity
 
-from testlib import namedTemporaryDir
 from monkeypatch import MonkeyPatchScope
 
 from integration.sslhelper import DEAFAULT_SSL_CONTEXT
+from testlib import ipv6_enabled
 
 PERMUTATIONS = [[True], [False]]
 
@@ -68,21 +66,22 @@ class FakeClientIf(object):
     def ready(self):
         return True
 
-    def notify(self, event_id, params=None):
+    def notify(self, event_id, params=None, destination=None):
         if not params:
             params = {}
 
+        if destination is None:
+            destination = self.dest
+
+        server = self.json_binding.reactor.server
+
         notification = Notification(
             event_id,
-            self._send_notification,
+            lambda message: server.send(message, destination),
             self.json_binding.bridge.event_schema
         )
         notification.emit(params)
 
-    def _send_notification(self, message):
-        server = self.json_binding.reactor.server
-        server.send(message, self.dest)
-
 
 @contextmanager
 def constructAcceptor(log, ssl, jsonBridge,
@@ -91,7 +90,7 @@ def constructAcceptor(log, ssl, jsonBridge,
     reactor = Reactor()
     acceptor = MultiProtocolAcceptor(
         reactor,
-        "::1",
+        "::1" if ipv6_enabled() else "127.0.0.1",
         0,
         sslctx,
     )
@@ -108,28 +107,26 @@ def constructAcceptor(log, ssl, jsonBridge,
 
     cif.json_binding = json_binding
 
-    with namedTemporaryDir() as tmp_dir:
-        client_log = os.path.join(tmp_dir, 'client.log')
-        with MonkeyPatchScope([
-            (API.clientIF, 'getInstance', lambda _: cif),
-            (connectivity, 'P_VDSM_CLIENT_LOG', client_log)
-        ]):
-            jsonBridge.cif = cif
+    with MonkeyPatchScope([
+        (API.clientIF, 'getInstance', lambda _: cif),
+        (API, 'confirm_connectivity', lambda: None)
+    ]):
+        jsonBridge.cif = cif
 
-            stompDetector = StompDetector(json_binding)
-            acceptor.add_detector(stompDetector)
+        stompDetector = StompDetector(json_binding)
+        acceptor.add_detector(stompDetector)
 
-            thread = threading.Thread(target=reactor.process_requests,
-                                      name='Detector thread')
-            thread.setDaemon(True)
-            thread.start()
+        thread = threading.Thread(target=reactor.process_requests,
+                                  name='Detector thread')
+        thread.setDaemon(True)
+        thread.start()
 
-            try:
-                yield acceptor
-            finally:
-                acceptor.stop()
-                json_binding.stop()
-                scheduler.stop(wait=False)
+        try:
+            yield acceptor
+        finally:
+            acceptor.stop()
+            json_binding.stop()
+            scheduler.stop(wait=False)
 
 
 @contextmanager
