@@ -29,12 +29,16 @@ import pytest
 
 from vdsm.common import fileutils
 from vdsm.network import kernelconfig
+from vdsm.network.canonicalize import bridge_opts_dict_to_sorted_str
+from vdsm.network.canonicalize import bridge_opts_str_to_dict
 from vdsm.network.ip import dhclient
 from vdsm.network.ip.address import ipv6_supported, prefix2netmask
 from vdsm.network.link.iface import iface
 from vdsm.network.link.bond import sysfs_options as bond_options
 from vdsm.network.link.bond import sysfs_options_mapper as bond_opts_mapper
+from vdsm.network.netinfo import bridges
 from vdsm.network.netlink import monitor
+from vdsm.network.netlink import waitfor
 
 from functional.utils import getProxy, SUCCESS
 
@@ -172,8 +176,8 @@ class NetFuncTestCase(object):
     def _assertCustomBridgeOpts(self, netattrs, bridge_caps):
         custom_attrs = netattrs.get('custom', {})
         if 'bridge_opts' in custom_attrs:
-            req_bridge_opts = (opt.split('=', 1) for opt in
-                               custom_attrs['bridge_opts'].split(' '))
+            req_bridge_opts = dict([opt.split('=', 1) for opt in
+                                    custom_attrs['bridge_opts'].split(' ')])
             bridge_opts_caps = bridge_caps['opts']
             for br_opt, br_val in six.iteritems(req_bridge_opts):
                 assert br_val == bridge_opts_caps[br_opt]
@@ -219,6 +223,23 @@ class NetFuncTestCase(object):
         running_mtu = netinfo.networks[netname]['mtu']
         assert requested_mtu == running_mtu
 
+    def assertLinkMtu(self, devname, netattrs):
+        requested_mtu = netattrs.get('mtu', 1500)
+        netinfo = _normalize_caps(self.netinfo)
+        if devname in netinfo.nics:
+            running_mtu = netinfo.nics[devname]['mtu']
+        elif devname in netinfo.bondings:
+            running_mtu = netinfo.bondings[devname]['mtu']
+        elif devname in netinfo.vlans:
+            running_mtu = netinfo.vlans[devname]['mtu']
+        elif devname in netinfo.bridges:
+            running_mtu = netinfo.bridges[devname]['mtu']
+        elif devname in netinfo.networks:
+            running_mtu = netinfo.networks[devname]['mtu']
+        else:
+            raise DeviceNotInCapsError(devname)
+        assert requested_mtu == int(running_mtu)
+
     def assertBond(self, bond, attrs):
         self.assertBondExists(bond)
         self.assertBondSlaves(bond, attrs['nics'])
@@ -226,6 +247,7 @@ class NetFuncTestCase(object):
             self.assertBondOptions(bond, attrs['options'])
         self.assertBondExistsInRunninng(bond, attrs['nics'])
         self.assertBondSwitchType(bond, attrs)
+        self.assertBondHwAddress(bond, attrs)
 
     def assertBondExists(self, bond):
         assert bond in self.netinfo.bondings
@@ -248,6 +270,12 @@ class NetFuncTestCase(object):
         running_switch = self.netinfo.bondings[bondname]['switch']
         assert requested_switch == running_switch
 
+    def assertBondHwAddress(self, bondname, bondattrs):
+        requested_hwaddress = bondattrs.get('hwaddr')
+        if requested_hwaddress:
+            actual_hwaddress = self.netinfo.bondings[bondname]['hwaddr']
+            assert requested_hwaddress == actual_hwaddress
+
     def assertNoBond(self, bond):
         self.assertNoBondExists(bond)
         self.assertNoBondExistsInRunning(bond)
@@ -412,6 +440,7 @@ class NetFuncTestCase(object):
 
         netinfo = _normalize_caps(self.netinfo)
         kernel_config = kernelconfig.KernelConfig(netinfo)
+        _extend_with_bridge_opts(kernel_config, running_config)
         kernel_config = kernel_config.as_unicode()
 
         # Do not use KernelConfig.__eq__ to get a better exception if something
@@ -427,6 +456,24 @@ class NetFuncTestCase(object):
             self.vdsm_proxy.setSafeNetworkConfig()
 
 
+def _extend_with_bridge_opts(kernel_config, running_config):
+    for net, attrs in six.viewitems(running_config['networks']):
+        if not attrs['bridged']:
+            continue
+        if net not in kernel_config.networks:
+            continue
+        running_opts_str = attrs.get('custom', {}).get('bridge_opts')
+        if not running_opts_str:
+            continue
+        running_opts_dict = bridge_opts_str_to_dict(running_opts_str)
+        kernel_opts_dict = {
+            key: val for key, val in six.viewitems(bridges.bridge_options(net))
+            if key in running_opts_dict}
+        kernel_opts_str = bridge_opts_dict_to_sorted_str(kernel_opts_dict)
+        kernel_config.networks[net].setdefault(
+            'custom', {})['bridge_opts'] = kernel_opts_str
+
+
 def _ipv4_is_unused(attrs):
     return 'ipaddr' not in attrs and attrs.get('bootproto') != 'dhcp'
 
@@ -487,7 +534,7 @@ class SetupNetworks(object):
                      for attr in six.itervalues(self.setup_networks)
                      if 'nic' in attr]
         for attr in six.itervalues(self.setup_bonds):
-            nics_used += attr['nics']
+            nics_used += attr.get('nics', [])
         for nic in nics_used:
             fileutils.rm_file(IFCFG_PREFIX + nic)
 
@@ -495,8 +542,11 @@ class SetupNetworks(object):
 
 
 @contextmanager
-def monitor_stable_link_state(device):
+def monitor_stable_link_state(device, wait_for_linkup=True):
     """Raises an exception if it detects that the device link state changes."""
+    if wait_for_linkup:
+        with waitfor.waitfor_linkup(device):
+            pass
     iface_properties = iface(device).properties()
     original_state = iface_properties['state']
     try:
@@ -597,3 +647,7 @@ def _gather_expected_ovs_links(net, attrs, netinfo):
         devs.add(nic)
 
     return devs
+
+
+class DeviceNotInCapsError(Exception):
+    pass
